mint

package
v0.0.0-...-2ff182f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 20, 2024 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the mint type in the database.
	Label = "mint"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldMinValuePerTx holds the string denoting the min_value_per_tx field in the database.
	FieldMinValuePerTx = "min_value_per_tx"
	// FieldMaxValuePerTx holds the string denoting the max_value_per_tx field in the database.
	FieldMaxValuePerTx = "max_value_per_tx"
	// FieldMinterAddress holds the string denoting the minter_address field in the database.
	FieldMinterAddress = "minter_address"
	// EdgeProject holds the string denoting the project edge name in mutations.
	EdgeProject = "project"
	// Table holds the table name of the mint in the database.
	Table = "mints"
	// ProjectTable is the table that holds the project relation/edge.
	ProjectTable = "mints"
	// ProjectInverseTable is the table name for the Project entity.
	// It exists in this package in order to avoid circular dependency with the "project" package.
	ProjectInverseTable = "projects"
	// ProjectColumn is the table column denoting the project relation/edge.
	ProjectColumn = "project_mint"
)

Variables

Columns holds all SQL columns for mint fields.

var ForeignKeys = []string{
	"project_mint",
}

ForeignKeys holds the SQL foreign-keys that are owned by the "mints" table and are not defined as standalone fields in the schema.

Functions

func And

func And(predicates ...predicate.Mint) predicate.Mint

And groups predicates with the AND operator between them.

func HasProject

func HasProject() predicate.Mint

HasProject applies the HasEdge predicate on the "project" edge.

func HasProjectWith

func HasProjectWith(preds ...predicate.Project) predicate.Mint

HasProjectWith applies the HasEdge predicate on the "project" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.Mint

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Mint

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Mint

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Mint

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Mint

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Mint

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Mint

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Mint

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Mint

IDNotIn applies the NotIn predicate on the ID field.

func MaxValuePerTx

func MaxValuePerTx(v string) predicate.Mint

MaxValuePerTx applies equality check predicate on the "max_value_per_tx" field. It's identical to MaxValuePerTxEQ.

func MaxValuePerTxContains

func MaxValuePerTxContains(v string) predicate.Mint

MaxValuePerTxContains applies the Contains predicate on the "max_value_per_tx" field.

func MaxValuePerTxContainsFold

func MaxValuePerTxContainsFold(v string) predicate.Mint

MaxValuePerTxContainsFold applies the ContainsFold predicate on the "max_value_per_tx" field.

func MaxValuePerTxEQ

func MaxValuePerTxEQ(v string) predicate.Mint

MaxValuePerTxEQ applies the EQ predicate on the "max_value_per_tx" field.

func MaxValuePerTxEqualFold

func MaxValuePerTxEqualFold(v string) predicate.Mint

MaxValuePerTxEqualFold applies the EqualFold predicate on the "max_value_per_tx" field.

func MaxValuePerTxGT

func MaxValuePerTxGT(v string) predicate.Mint

MaxValuePerTxGT applies the GT predicate on the "max_value_per_tx" field.

func MaxValuePerTxGTE

func MaxValuePerTxGTE(v string) predicate.Mint

MaxValuePerTxGTE applies the GTE predicate on the "max_value_per_tx" field.

func MaxValuePerTxHasPrefix

func MaxValuePerTxHasPrefix(v string) predicate.Mint

MaxValuePerTxHasPrefix applies the HasPrefix predicate on the "max_value_per_tx" field.

func MaxValuePerTxHasSuffix

func MaxValuePerTxHasSuffix(v string) predicate.Mint

MaxValuePerTxHasSuffix applies the HasSuffix predicate on the "max_value_per_tx" field.

func MaxValuePerTxIn

func MaxValuePerTxIn(vs ...string) predicate.Mint

MaxValuePerTxIn applies the In predicate on the "max_value_per_tx" field.

func MaxValuePerTxLT

func MaxValuePerTxLT(v string) predicate.Mint

MaxValuePerTxLT applies the LT predicate on the "max_value_per_tx" field.

func MaxValuePerTxLTE

func MaxValuePerTxLTE(v string) predicate.Mint

MaxValuePerTxLTE applies the LTE predicate on the "max_value_per_tx" field.

func MaxValuePerTxNEQ

func MaxValuePerTxNEQ(v string) predicate.Mint

MaxValuePerTxNEQ applies the NEQ predicate on the "max_value_per_tx" field.

func MaxValuePerTxNotIn

func MaxValuePerTxNotIn(vs ...string) predicate.Mint

MaxValuePerTxNotIn applies the NotIn predicate on the "max_value_per_tx" field.

func MinValuePerTx

func MinValuePerTx(v string) predicate.Mint

MinValuePerTx applies equality check predicate on the "min_value_per_tx" field. It's identical to MinValuePerTxEQ.

func MinValuePerTxContains

func MinValuePerTxContains(v string) predicate.Mint

MinValuePerTxContains applies the Contains predicate on the "min_value_per_tx" field.

func MinValuePerTxContainsFold

func MinValuePerTxContainsFold(v string) predicate.Mint

MinValuePerTxContainsFold applies the ContainsFold predicate on the "min_value_per_tx" field.

func MinValuePerTxEQ

func MinValuePerTxEQ(v string) predicate.Mint

MinValuePerTxEQ applies the EQ predicate on the "min_value_per_tx" field.

func MinValuePerTxEqualFold

func MinValuePerTxEqualFold(v string) predicate.Mint

MinValuePerTxEqualFold applies the EqualFold predicate on the "min_value_per_tx" field.

func MinValuePerTxGT

func MinValuePerTxGT(v string) predicate.Mint

MinValuePerTxGT applies the GT predicate on the "min_value_per_tx" field.

func MinValuePerTxGTE

func MinValuePerTxGTE(v string) predicate.Mint

MinValuePerTxGTE applies the GTE predicate on the "min_value_per_tx" field.

func MinValuePerTxHasPrefix

func MinValuePerTxHasPrefix(v string) predicate.Mint

MinValuePerTxHasPrefix applies the HasPrefix predicate on the "min_value_per_tx" field.

func MinValuePerTxHasSuffix

func MinValuePerTxHasSuffix(v string) predicate.Mint

MinValuePerTxHasSuffix applies the HasSuffix predicate on the "min_value_per_tx" field.

func MinValuePerTxIn

func MinValuePerTxIn(vs ...string) predicate.Mint

MinValuePerTxIn applies the In predicate on the "min_value_per_tx" field.

func MinValuePerTxLT

func MinValuePerTxLT(v string) predicate.Mint

MinValuePerTxLT applies the LT predicate on the "min_value_per_tx" field.

func MinValuePerTxLTE

func MinValuePerTxLTE(v string) predicate.Mint

MinValuePerTxLTE applies the LTE predicate on the "min_value_per_tx" field.

func MinValuePerTxNEQ

func MinValuePerTxNEQ(v string) predicate.Mint

MinValuePerTxNEQ applies the NEQ predicate on the "min_value_per_tx" field.

func MinValuePerTxNotIn

func MinValuePerTxNotIn(vs ...string) predicate.Mint

MinValuePerTxNotIn applies the NotIn predicate on the "min_value_per_tx" field.

func MinterAddress

func MinterAddress(v string) predicate.Mint

MinterAddress applies equality check predicate on the "minter_address" field. It's identical to MinterAddressEQ.

func MinterAddressContains

func MinterAddressContains(v string) predicate.Mint

MinterAddressContains applies the Contains predicate on the "minter_address" field.

func MinterAddressContainsFold

func MinterAddressContainsFold(v string) predicate.Mint

MinterAddressContainsFold applies the ContainsFold predicate on the "minter_address" field.

func MinterAddressEQ

func MinterAddressEQ(v string) predicate.Mint

MinterAddressEQ applies the EQ predicate on the "minter_address" field.

func MinterAddressEqualFold

func MinterAddressEqualFold(v string) predicate.Mint

MinterAddressEqualFold applies the EqualFold predicate on the "minter_address" field.

func MinterAddressGT

func MinterAddressGT(v string) predicate.Mint

MinterAddressGT applies the GT predicate on the "minter_address" field.

func MinterAddressGTE

func MinterAddressGTE(v string) predicate.Mint

MinterAddressGTE applies the GTE predicate on the "minter_address" field.

func MinterAddressHasPrefix

func MinterAddressHasPrefix(v string) predicate.Mint

MinterAddressHasPrefix applies the HasPrefix predicate on the "minter_address" field.

func MinterAddressHasSuffix

func MinterAddressHasSuffix(v string) predicate.Mint

MinterAddressHasSuffix applies the HasSuffix predicate on the "minter_address" field.

func MinterAddressIn

func MinterAddressIn(vs ...string) predicate.Mint

MinterAddressIn applies the In predicate on the "minter_address" field.

func MinterAddressLT

func MinterAddressLT(v string) predicate.Mint

MinterAddressLT applies the LT predicate on the "minter_address" field.

func MinterAddressLTE

func MinterAddressLTE(v string) predicate.Mint

MinterAddressLTE applies the LTE predicate on the "minter_address" field.

func MinterAddressNEQ

func MinterAddressNEQ(v string) predicate.Mint

MinterAddressNEQ applies the NEQ predicate on the "minter_address" field.

func MinterAddressNotIn

func MinterAddressNotIn(vs ...string) predicate.Mint

MinterAddressNotIn applies the NotIn predicate on the "minter_address" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Mint) predicate.Mint

Or groups predicates with the OR operator between them.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Mint queries.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByMaxValuePerTx

func ByMaxValuePerTx(opts ...sql.OrderTermOption) OrderOption

ByMaxValuePerTx orders the results by the max_value_per_tx field.

func ByMinValuePerTx

func ByMinValuePerTx(opts ...sql.OrderTermOption) OrderOption

ByMinValuePerTx orders the results by the min_value_per_tx field.

func ByMinterAddress

func ByMinterAddress(opts ...sql.OrderTermOption) OrderOption

ByMinterAddress orders the results by the minter_address field.

func ByProjectField

func ByProjectField(field string, opts ...sql.OrderTermOption) OrderOption

ByProjectField orders the results by project field.

Jump to