project

package
v0.0.0-...-2ff182f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 20, 2024 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the project type in the database.
	Label = "project"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldAddress holds the string denoting the address field in the database.
	FieldAddress = "address"
	// FieldSlot holds the string denoting the slot field in the database.
	FieldSlot = "slot"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldSlug holds the string denoting the slug field in the database.
	FieldSlug = "slug"
	// FieldValueDecimal holds the string denoting the value_decimal field in the database.
	FieldValueDecimal = "value_decimal"
	// FieldForecastedApr holds the string denoting the forecasted_apr field in the database.
	FieldForecastedApr = "forecasted_apr"
	// FieldTotalValue holds the string denoting the total_value field in the database.
	FieldTotalValue = "total_value"
	// FieldPaymentToken holds the string denoting the payment_token field in the database.
	FieldPaymentToken = "payment_token"
	// FieldMetadata holds the string denoting the metadata field in the database.
	FieldMetadata = "metadata"
	// EdgeMint holds the string denoting the mint edge name in mutations.
	EdgeMint = "mint"
	// EdgeLaunchpad holds the string denoting the launchpad edge name in mutations.
	EdgeLaunchpad = "launchpad"
	// Table holds the table name of the project in the database.
	Table = "projects"
	// MintTable is the table that holds the mint relation/edge.
	MintTable = "mints"
	// MintInverseTable is the table name for the Mint entity.
	// It exists in this package in order to avoid circular dependency with the "mint" package.
	MintInverseTable = "mints"
	// MintColumn is the table column denoting the mint relation/edge.
	MintColumn = "project_mint"
	// LaunchpadTable is the table that holds the launchpad relation/edge.
	LaunchpadTable = "launchpads"
	// LaunchpadInverseTable is the table name for the Launchpad entity.
	// It exists in this package in order to avoid circular dependency with the "launchpad" package.
	LaunchpadInverseTable = "launchpads"
	// LaunchpadColumn is the table column denoting the launchpad relation/edge.
	LaunchpadColumn = "project_launchpad"
)

Variables

Columns holds all SQL columns for project fields.

Functions

func Address

func Address(v string) predicate.Project

Address applies equality check predicate on the "address" field. It's identical to AddressEQ.

func AddressContains

func AddressContains(v string) predicate.Project

AddressContains applies the Contains predicate on the "address" field.

func AddressContainsFold

func AddressContainsFold(v string) predicate.Project

AddressContainsFold applies the ContainsFold predicate on the "address" field.

func AddressEQ

func AddressEQ(v string) predicate.Project

AddressEQ applies the EQ predicate on the "address" field.

func AddressEqualFold

func AddressEqualFold(v string) predicate.Project

AddressEqualFold applies the EqualFold predicate on the "address" field.

func AddressGT

func AddressGT(v string) predicate.Project

AddressGT applies the GT predicate on the "address" field.

func AddressGTE

func AddressGTE(v string) predicate.Project

AddressGTE applies the GTE predicate on the "address" field.

func AddressHasPrefix

func AddressHasPrefix(v string) predicate.Project

AddressHasPrefix applies the HasPrefix predicate on the "address" field.

func AddressHasSuffix

func AddressHasSuffix(v string) predicate.Project

AddressHasSuffix applies the HasSuffix predicate on the "address" field.

func AddressIn

func AddressIn(vs ...string) predicate.Project

AddressIn applies the In predicate on the "address" field.

func AddressLT

func AddressLT(v string) predicate.Project

AddressLT applies the LT predicate on the "address" field.

func AddressLTE

func AddressLTE(v string) predicate.Project

AddressLTE applies the LTE predicate on the "address" field.

func AddressNEQ

func AddressNEQ(v string) predicate.Project

AddressNEQ applies the NEQ predicate on the "address" field.

func AddressNotIn

func AddressNotIn(vs ...string) predicate.Project

AddressNotIn applies the NotIn predicate on the "address" field.

func And

func And(predicates ...predicate.Project) predicate.Project

And groups predicates with the AND operator between them.

func ForecastedApr

func ForecastedApr(v string) predicate.Project

ForecastedApr applies equality check predicate on the "forecasted_apr" field. It's identical to ForecastedAprEQ.

func ForecastedAprContains

func ForecastedAprContains(v string) predicate.Project

ForecastedAprContains applies the Contains predicate on the "forecasted_apr" field.

func ForecastedAprContainsFold

func ForecastedAprContainsFold(v string) predicate.Project

ForecastedAprContainsFold applies the ContainsFold predicate on the "forecasted_apr" field.

func ForecastedAprEQ

func ForecastedAprEQ(v string) predicate.Project

ForecastedAprEQ applies the EQ predicate on the "forecasted_apr" field.

func ForecastedAprEqualFold

func ForecastedAprEqualFold(v string) predicate.Project

ForecastedAprEqualFold applies the EqualFold predicate on the "forecasted_apr" field.

func ForecastedAprGT

func ForecastedAprGT(v string) predicate.Project

ForecastedAprGT applies the GT predicate on the "forecasted_apr" field.

func ForecastedAprGTE

func ForecastedAprGTE(v string) predicate.Project

ForecastedAprGTE applies the GTE predicate on the "forecasted_apr" field.

func ForecastedAprHasPrefix

func ForecastedAprHasPrefix(v string) predicate.Project

ForecastedAprHasPrefix applies the HasPrefix predicate on the "forecasted_apr" field.

func ForecastedAprHasSuffix

func ForecastedAprHasSuffix(v string) predicate.Project

ForecastedAprHasSuffix applies the HasSuffix predicate on the "forecasted_apr" field.

func ForecastedAprIn

func ForecastedAprIn(vs ...string) predicate.Project

ForecastedAprIn applies the In predicate on the "forecasted_apr" field.

func ForecastedAprIsNil

func ForecastedAprIsNil() predicate.Project

ForecastedAprIsNil applies the IsNil predicate on the "forecasted_apr" field.

func ForecastedAprLT

func ForecastedAprLT(v string) predicate.Project

ForecastedAprLT applies the LT predicate on the "forecasted_apr" field.

func ForecastedAprLTE

func ForecastedAprLTE(v string) predicate.Project

ForecastedAprLTE applies the LTE predicate on the "forecasted_apr" field.

func ForecastedAprNEQ

func ForecastedAprNEQ(v string) predicate.Project

ForecastedAprNEQ applies the NEQ predicate on the "forecasted_apr" field.

func ForecastedAprNotIn

func ForecastedAprNotIn(vs ...string) predicate.Project

ForecastedAprNotIn applies the NotIn predicate on the "forecasted_apr" field.

func ForecastedAprNotNil

func ForecastedAprNotNil() predicate.Project

ForecastedAprNotNil applies the NotNil predicate on the "forecasted_apr" field.

func HasLaunchpad

func HasLaunchpad() predicate.Project

HasLaunchpad applies the HasEdge predicate on the "launchpad" edge.

func HasLaunchpadWith

func HasLaunchpadWith(preds ...predicate.Launchpad) predicate.Project

HasLaunchpadWith applies the HasEdge predicate on the "launchpad" edge with a given conditions (other predicates).

func HasMint

func HasMint() predicate.Project

HasMint applies the HasEdge predicate on the "mint" edge.

func HasMintWith

func HasMintWith(preds ...predicate.Mint) predicate.Project

HasMintWith applies the HasEdge predicate on the "mint" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.Project

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Project

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Project

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Project

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Project

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Project

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Project

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Project

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Project

IDNotIn applies the NotIn predicate on the ID field.

func Name

func Name(v string) predicate.Project

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Project

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Project

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Project

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Project

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.Project

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Project

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Project

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Project

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Project

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Project

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Project

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.Project

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Project

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Project) predicate.Project

Or groups predicates with the OR operator between them.

func Slot

func Slot(v int) predicate.Project

Slot applies equality check predicate on the "slot" field. It's identical to SlotEQ.

func SlotEQ

func SlotEQ(v int) predicate.Project

SlotEQ applies the EQ predicate on the "slot" field.

func SlotGT

func SlotGT(v int) predicate.Project

SlotGT applies the GT predicate on the "slot" field.

func SlotGTE

func SlotGTE(v int) predicate.Project

SlotGTE applies the GTE predicate on the "slot" field.

func SlotIn

func SlotIn(vs ...int) predicate.Project

SlotIn applies the In predicate on the "slot" field.

func SlotLT

func SlotLT(v int) predicate.Project

SlotLT applies the LT predicate on the "slot" field.

func SlotLTE

func SlotLTE(v int) predicate.Project

SlotLTE applies the LTE predicate on the "slot" field.

func SlotNEQ

func SlotNEQ(v int) predicate.Project

SlotNEQ applies the NEQ predicate on the "slot" field.

func SlotNotIn

func SlotNotIn(vs ...int) predicate.Project

SlotNotIn applies the NotIn predicate on the "slot" field.

func Slug

func Slug(v string) predicate.Project

Slug applies equality check predicate on the "slug" field. It's identical to SlugEQ.

func SlugContains

func SlugContains(v string) predicate.Project

SlugContains applies the Contains predicate on the "slug" field.

func SlugContainsFold

func SlugContainsFold(v string) predicate.Project

SlugContainsFold applies the ContainsFold predicate on the "slug" field.

func SlugEQ

func SlugEQ(v string) predicate.Project

SlugEQ applies the EQ predicate on the "slug" field.

func SlugEqualFold

func SlugEqualFold(v string) predicate.Project

SlugEqualFold applies the EqualFold predicate on the "slug" field.

func SlugGT

func SlugGT(v string) predicate.Project

SlugGT applies the GT predicate on the "slug" field.

func SlugGTE

func SlugGTE(v string) predicate.Project

SlugGTE applies the GTE predicate on the "slug" field.

func SlugHasPrefix

func SlugHasPrefix(v string) predicate.Project

SlugHasPrefix applies the HasPrefix predicate on the "slug" field.

func SlugHasSuffix

func SlugHasSuffix(v string) predicate.Project

SlugHasSuffix applies the HasSuffix predicate on the "slug" field.

func SlugIn

func SlugIn(vs ...string) predicate.Project

SlugIn applies the In predicate on the "slug" field.

func SlugLT

func SlugLT(v string) predicate.Project

SlugLT applies the LT predicate on the "slug" field.

func SlugLTE

func SlugLTE(v string) predicate.Project

SlugLTE applies the LTE predicate on the "slug" field.

func SlugNEQ

func SlugNEQ(v string) predicate.Project

SlugNEQ applies the NEQ predicate on the "slug" field.

func SlugNotIn

func SlugNotIn(vs ...string) predicate.Project

SlugNotIn applies the NotIn predicate on the "slug" field.

func TotalValue

func TotalValue(v string) predicate.Project

TotalValue applies equality check predicate on the "total_value" field. It's identical to TotalValueEQ.

func TotalValueContains

func TotalValueContains(v string) predicate.Project

TotalValueContains applies the Contains predicate on the "total_value" field.

func TotalValueContainsFold

func TotalValueContainsFold(v string) predicate.Project

TotalValueContainsFold applies the ContainsFold predicate on the "total_value" field.

func TotalValueEQ

func TotalValueEQ(v string) predicate.Project

TotalValueEQ applies the EQ predicate on the "total_value" field.

func TotalValueEqualFold

func TotalValueEqualFold(v string) predicate.Project

TotalValueEqualFold applies the EqualFold predicate on the "total_value" field.

func TotalValueGT

func TotalValueGT(v string) predicate.Project

TotalValueGT applies the GT predicate on the "total_value" field.

func TotalValueGTE

func TotalValueGTE(v string) predicate.Project

TotalValueGTE applies the GTE predicate on the "total_value" field.

func TotalValueHasPrefix

func TotalValueHasPrefix(v string) predicate.Project

TotalValueHasPrefix applies the HasPrefix predicate on the "total_value" field.

func TotalValueHasSuffix

func TotalValueHasSuffix(v string) predicate.Project

TotalValueHasSuffix applies the HasSuffix predicate on the "total_value" field.

func TotalValueIn

func TotalValueIn(vs ...string) predicate.Project

TotalValueIn applies the In predicate on the "total_value" field.

func TotalValueLT

func TotalValueLT(v string) predicate.Project

TotalValueLT applies the LT predicate on the "total_value" field.

func TotalValueLTE

func TotalValueLTE(v string) predicate.Project

TotalValueLTE applies the LTE predicate on the "total_value" field.

func TotalValueNEQ

func TotalValueNEQ(v string) predicate.Project

TotalValueNEQ applies the NEQ predicate on the "total_value" field.

func TotalValueNotIn

func TotalValueNotIn(vs ...string) predicate.Project

TotalValueNotIn applies the NotIn predicate on the "total_value" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func ValueDecimal

func ValueDecimal(v int) predicate.Project

ValueDecimal applies equality check predicate on the "value_decimal" field. It's identical to ValueDecimalEQ.

func ValueDecimalEQ

func ValueDecimalEQ(v int) predicate.Project

ValueDecimalEQ applies the EQ predicate on the "value_decimal" field.

func ValueDecimalGT

func ValueDecimalGT(v int) predicate.Project

ValueDecimalGT applies the GT predicate on the "value_decimal" field.

func ValueDecimalGTE

func ValueDecimalGTE(v int) predicate.Project

ValueDecimalGTE applies the GTE predicate on the "value_decimal" field.

func ValueDecimalIn

func ValueDecimalIn(vs ...int) predicate.Project

ValueDecimalIn applies the In predicate on the "value_decimal" field.

func ValueDecimalLT

func ValueDecimalLT(v int) predicate.Project

ValueDecimalLT applies the LT predicate on the "value_decimal" field.

func ValueDecimalLTE

func ValueDecimalLTE(v int) predicate.Project

ValueDecimalLTE applies the LTE predicate on the "value_decimal" field.

func ValueDecimalNEQ

func ValueDecimalNEQ(v int) predicate.Project

ValueDecimalNEQ applies the NEQ predicate on the "value_decimal" field.

func ValueDecimalNotIn

func ValueDecimalNotIn(vs ...int) predicate.Project

ValueDecimalNotIn applies the NotIn predicate on the "value_decimal" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Project queries.

func ByAddress

func ByAddress(opts ...sql.OrderTermOption) OrderOption

ByAddress orders the results by the address field.

func ByForecastedApr

func ByForecastedApr(opts ...sql.OrderTermOption) OrderOption

ByForecastedApr orders the results by the forecasted_apr field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByLaunchpadField

func ByLaunchpadField(field string, opts ...sql.OrderTermOption) OrderOption

ByLaunchpadField orders the results by launchpad field.

func ByMintField

func ByMintField(field string, opts ...sql.OrderTermOption) OrderOption

ByMintField orders the results by mint field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func BySlot

func BySlot(opts ...sql.OrderTermOption) OrderOption

BySlot orders the results by the slot field.

func BySlug

func BySlug(opts ...sql.OrderTermOption) OrderOption

BySlug orders the results by the slug field.

func ByTotalValue

func ByTotalValue(opts ...sql.OrderTermOption) OrderOption

ByTotalValue orders the results by the total_value field.

func ByValueDecimal

func ByValueDecimal(opts ...sql.OrderTermOption) OrderOption

ByValueDecimal orders the results by the value_decimal field.

Jump to