Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Mint) predicate.Mint
- func HasProject() predicate.Mint
- func HasProjectWith(preds ...predicate.Project) predicate.Mint
- func ID(id int) predicate.Mint
- func IDEQ(id int) predicate.Mint
- func IDGT(id int) predicate.Mint
- func IDGTE(id int) predicate.Mint
- func IDIn(ids ...int) predicate.Mint
- func IDLT(id int) predicate.Mint
- func IDLTE(id int) predicate.Mint
- func IDNEQ(id int) predicate.Mint
- func IDNotIn(ids ...int) predicate.Mint
- func MaxValuePerTx(v string) predicate.Mint
- func MaxValuePerTxContains(v string) predicate.Mint
- func MaxValuePerTxContainsFold(v string) predicate.Mint
- func MaxValuePerTxEQ(v string) predicate.Mint
- func MaxValuePerTxEqualFold(v string) predicate.Mint
- func MaxValuePerTxGT(v string) predicate.Mint
- func MaxValuePerTxGTE(v string) predicate.Mint
- func MaxValuePerTxHasPrefix(v string) predicate.Mint
- func MaxValuePerTxHasSuffix(v string) predicate.Mint
- func MaxValuePerTxIn(vs ...string) predicate.Mint
- func MaxValuePerTxLT(v string) predicate.Mint
- func MaxValuePerTxLTE(v string) predicate.Mint
- func MaxValuePerTxNEQ(v string) predicate.Mint
- func MaxValuePerTxNotIn(vs ...string) predicate.Mint
- func MinValuePerTx(v string) predicate.Mint
- func MinValuePerTxContains(v string) predicate.Mint
- func MinValuePerTxContainsFold(v string) predicate.Mint
- func MinValuePerTxEQ(v string) predicate.Mint
- func MinValuePerTxEqualFold(v string) predicate.Mint
- func MinValuePerTxGT(v string) predicate.Mint
- func MinValuePerTxGTE(v string) predicate.Mint
- func MinValuePerTxHasPrefix(v string) predicate.Mint
- func MinValuePerTxHasSuffix(v string) predicate.Mint
- func MinValuePerTxIn(vs ...string) predicate.Mint
- func MinValuePerTxLT(v string) predicate.Mint
- func MinValuePerTxLTE(v string) predicate.Mint
- func MinValuePerTxNEQ(v string) predicate.Mint
- func MinValuePerTxNotIn(vs ...string) predicate.Mint
- func MinterAddress(v string) predicate.Mint
- func MinterAddressContains(v string) predicate.Mint
- func MinterAddressContainsFold(v string) predicate.Mint
- func MinterAddressEQ(v string) predicate.Mint
- func MinterAddressEqualFold(v string) predicate.Mint
- func MinterAddressGT(v string) predicate.Mint
- func MinterAddressGTE(v string) predicate.Mint
- func MinterAddressHasPrefix(v string) predicate.Mint
- func MinterAddressHasSuffix(v string) predicate.Mint
- func MinterAddressIn(vs ...string) predicate.Mint
- func MinterAddressLT(v string) predicate.Mint
- func MinterAddressLTE(v string) predicate.Mint
- func MinterAddressNEQ(v string) predicate.Mint
- func MinterAddressNotIn(vs ...string) predicate.Mint
- func Not(p predicate.Mint) predicate.Mint
- func Or(predicates ...predicate.Mint) predicate.Mint
- func ValidColumn(column string) bool
- type OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByMaxValuePerTx(opts ...sql.OrderTermOption) OrderOption
- func ByMinValuePerTx(opts ...sql.OrderTermOption) OrderOption
- func ByMinterAddress(opts ...sql.OrderTermOption) OrderOption
- func ByProjectField(field string, opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the mint type in the database. Label = "mint" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldMinValuePerTx holds the string denoting the min_value_per_tx field in the database. FieldMinValuePerTx = "min_value_per_tx" // FieldMaxValuePerTx holds the string denoting the max_value_per_tx field in the database. FieldMaxValuePerTx = "max_value_per_tx" // FieldMinterAddress holds the string denoting the minter_address field in the database. FieldMinterAddress = "minter_address" // EdgeProject holds the string denoting the project edge name in mutations. EdgeProject = "project" // Table holds the table name of the mint in the database. Table = "mints" // ProjectTable is the table that holds the project relation/edge. ProjectTable = "mints" // ProjectInverseTable is the table name for the Project entity. // It exists in this package in order to avoid circular dependency with the "project" package. ProjectInverseTable = "projects" // ProjectColumn is the table column denoting the project relation/edge. ProjectColumn = "project_mint" )
Variables ¶
var Columns = []string{ FieldID, FieldMinValuePerTx, FieldMaxValuePerTx, FieldMinterAddress, }
Columns holds all SQL columns for mint fields.
var ForeignKeys = []string{
"project_mint",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "mints" table and are not defined as standalone fields in the schema.
Functions ¶
func HasProject ¶
HasProject applies the HasEdge predicate on the "project" edge.
func HasProjectWith ¶
HasProjectWith applies the HasEdge predicate on the "project" edge with a given conditions (other predicates).
func MaxValuePerTx ¶
MaxValuePerTx applies equality check predicate on the "max_value_per_tx" field. It's identical to MaxValuePerTxEQ.
func MaxValuePerTxContains ¶
MaxValuePerTxContains applies the Contains predicate on the "max_value_per_tx" field.
func MaxValuePerTxContainsFold ¶
MaxValuePerTxContainsFold applies the ContainsFold predicate on the "max_value_per_tx" field.
func MaxValuePerTxEQ ¶
MaxValuePerTxEQ applies the EQ predicate on the "max_value_per_tx" field.
func MaxValuePerTxEqualFold ¶
MaxValuePerTxEqualFold applies the EqualFold predicate on the "max_value_per_tx" field.
func MaxValuePerTxGT ¶
MaxValuePerTxGT applies the GT predicate on the "max_value_per_tx" field.
func MaxValuePerTxGTE ¶
MaxValuePerTxGTE applies the GTE predicate on the "max_value_per_tx" field.
func MaxValuePerTxHasPrefix ¶
MaxValuePerTxHasPrefix applies the HasPrefix predicate on the "max_value_per_tx" field.
func MaxValuePerTxHasSuffix ¶
MaxValuePerTxHasSuffix applies the HasSuffix predicate on the "max_value_per_tx" field.
func MaxValuePerTxIn ¶
MaxValuePerTxIn applies the In predicate on the "max_value_per_tx" field.
func MaxValuePerTxLT ¶
MaxValuePerTxLT applies the LT predicate on the "max_value_per_tx" field.
func MaxValuePerTxLTE ¶
MaxValuePerTxLTE applies the LTE predicate on the "max_value_per_tx" field.
func MaxValuePerTxNEQ ¶
MaxValuePerTxNEQ applies the NEQ predicate on the "max_value_per_tx" field.
func MaxValuePerTxNotIn ¶
MaxValuePerTxNotIn applies the NotIn predicate on the "max_value_per_tx" field.
func MinValuePerTx ¶
MinValuePerTx applies equality check predicate on the "min_value_per_tx" field. It's identical to MinValuePerTxEQ.
func MinValuePerTxContains ¶
MinValuePerTxContains applies the Contains predicate on the "min_value_per_tx" field.
func MinValuePerTxContainsFold ¶
MinValuePerTxContainsFold applies the ContainsFold predicate on the "min_value_per_tx" field.
func MinValuePerTxEQ ¶
MinValuePerTxEQ applies the EQ predicate on the "min_value_per_tx" field.
func MinValuePerTxEqualFold ¶
MinValuePerTxEqualFold applies the EqualFold predicate on the "min_value_per_tx" field.
func MinValuePerTxGT ¶
MinValuePerTxGT applies the GT predicate on the "min_value_per_tx" field.
func MinValuePerTxGTE ¶
MinValuePerTxGTE applies the GTE predicate on the "min_value_per_tx" field.
func MinValuePerTxHasPrefix ¶
MinValuePerTxHasPrefix applies the HasPrefix predicate on the "min_value_per_tx" field.
func MinValuePerTxHasSuffix ¶
MinValuePerTxHasSuffix applies the HasSuffix predicate on the "min_value_per_tx" field.
func MinValuePerTxIn ¶
MinValuePerTxIn applies the In predicate on the "min_value_per_tx" field.
func MinValuePerTxLT ¶
MinValuePerTxLT applies the LT predicate on the "min_value_per_tx" field.
func MinValuePerTxLTE ¶
MinValuePerTxLTE applies the LTE predicate on the "min_value_per_tx" field.
func MinValuePerTxNEQ ¶
MinValuePerTxNEQ applies the NEQ predicate on the "min_value_per_tx" field.
func MinValuePerTxNotIn ¶
MinValuePerTxNotIn applies the NotIn predicate on the "min_value_per_tx" field.
func MinterAddress ¶
MinterAddress applies equality check predicate on the "minter_address" field. It's identical to MinterAddressEQ.
func MinterAddressContains ¶
MinterAddressContains applies the Contains predicate on the "minter_address" field.
func MinterAddressContainsFold ¶
MinterAddressContainsFold applies the ContainsFold predicate on the "minter_address" field.
func MinterAddressEQ ¶
MinterAddressEQ applies the EQ predicate on the "minter_address" field.
func MinterAddressEqualFold ¶
MinterAddressEqualFold applies the EqualFold predicate on the "minter_address" field.
func MinterAddressGT ¶
MinterAddressGT applies the GT predicate on the "minter_address" field.
func MinterAddressGTE ¶
MinterAddressGTE applies the GTE predicate on the "minter_address" field.
func MinterAddressHasPrefix ¶
MinterAddressHasPrefix applies the HasPrefix predicate on the "minter_address" field.
func MinterAddressHasSuffix ¶
MinterAddressHasSuffix applies the HasSuffix predicate on the "minter_address" field.
func MinterAddressIn ¶
MinterAddressIn applies the In predicate on the "minter_address" field.
func MinterAddressLT ¶
MinterAddressLT applies the LT predicate on the "minter_address" field.
func MinterAddressLTE ¶
MinterAddressLTE applies the LTE predicate on the "minter_address" field.
func MinterAddressNEQ ¶
MinterAddressNEQ applies the NEQ predicate on the "minter_address" field.
func MinterAddressNotIn ¶
MinterAddressNotIn applies the NotIn predicate on the "minter_address" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Mint queries.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByMaxValuePerTx ¶
func ByMaxValuePerTx(opts ...sql.OrderTermOption) OrderOption
ByMaxValuePerTx orders the results by the max_value_per_tx field.
func ByMinValuePerTx ¶
func ByMinValuePerTx(opts ...sql.OrderTermOption) OrderOption
ByMinValuePerTx orders the results by the min_value_per_tx field.
func ByMinterAddress ¶
func ByMinterAddress(opts ...sql.OrderTermOption) OrderOption
ByMinterAddress orders the results by the minter_address field.
func ByProjectField ¶
func ByProjectField(field string, opts ...sql.OrderTermOption) OrderOption
ByProjectField orders the results by project field.