Documentation
¶
Index ¶
- Constants
- Variables
- func Address(v string) predicate.Project
- func AddressContains(v string) predicate.Project
- func AddressContainsFold(v string) predicate.Project
- func AddressEQ(v string) predicate.Project
- func AddressEqualFold(v string) predicate.Project
- func AddressGT(v string) predicate.Project
- func AddressGTE(v string) predicate.Project
- func AddressHasPrefix(v string) predicate.Project
- func AddressHasSuffix(v string) predicate.Project
- func AddressIn(vs ...string) predicate.Project
- func AddressLT(v string) predicate.Project
- func AddressLTE(v string) predicate.Project
- func AddressNEQ(v string) predicate.Project
- func AddressNotIn(vs ...string) predicate.Project
- func And(predicates ...predicate.Project) predicate.Project
- func ForecastedApr(v string) predicate.Project
- func ForecastedAprContains(v string) predicate.Project
- func ForecastedAprContainsFold(v string) predicate.Project
- func ForecastedAprEQ(v string) predicate.Project
- func ForecastedAprEqualFold(v string) predicate.Project
- func ForecastedAprGT(v string) predicate.Project
- func ForecastedAprGTE(v string) predicate.Project
- func ForecastedAprHasPrefix(v string) predicate.Project
- func ForecastedAprHasSuffix(v string) predicate.Project
- func ForecastedAprIn(vs ...string) predicate.Project
- func ForecastedAprIsNil() predicate.Project
- func ForecastedAprLT(v string) predicate.Project
- func ForecastedAprLTE(v string) predicate.Project
- func ForecastedAprNEQ(v string) predicate.Project
- func ForecastedAprNotIn(vs ...string) predicate.Project
- func ForecastedAprNotNil() predicate.Project
- func HasLaunchpad() predicate.Project
- func HasLaunchpadWith(preds ...predicate.Launchpad) predicate.Project
- func HasMint() predicate.Project
- func HasMintWith(preds ...predicate.Mint) predicate.Project
- func ID(id int) predicate.Project
- func IDEQ(id int) predicate.Project
- func IDGT(id int) predicate.Project
- func IDGTE(id int) predicate.Project
- func IDIn(ids ...int) predicate.Project
- func IDLT(id int) predicate.Project
- func IDLTE(id int) predicate.Project
- func IDNEQ(id int) predicate.Project
- func IDNotIn(ids ...int) predicate.Project
- func Name(v string) predicate.Project
- func NameContains(v string) predicate.Project
- func NameContainsFold(v string) predicate.Project
- func NameEQ(v string) predicate.Project
- func NameEqualFold(v string) predicate.Project
- func NameGT(v string) predicate.Project
- func NameGTE(v string) predicate.Project
- func NameHasPrefix(v string) predicate.Project
- func NameHasSuffix(v string) predicate.Project
- func NameIn(vs ...string) predicate.Project
- func NameLT(v string) predicate.Project
- func NameLTE(v string) predicate.Project
- func NameNEQ(v string) predicate.Project
- func NameNotIn(vs ...string) predicate.Project
- func Not(p predicate.Project) predicate.Project
- func Or(predicates ...predicate.Project) predicate.Project
- func Slot(v int) predicate.Project
- func SlotEQ(v int) predicate.Project
- func SlotGT(v int) predicate.Project
- func SlotGTE(v int) predicate.Project
- func SlotIn(vs ...int) predicate.Project
- func SlotLT(v int) predicate.Project
- func SlotLTE(v int) predicate.Project
- func SlotNEQ(v int) predicate.Project
- func SlotNotIn(vs ...int) predicate.Project
- func Slug(v string) predicate.Project
- func SlugContains(v string) predicate.Project
- func SlugContainsFold(v string) predicate.Project
- func SlugEQ(v string) predicate.Project
- func SlugEqualFold(v string) predicate.Project
- func SlugGT(v string) predicate.Project
- func SlugGTE(v string) predicate.Project
- func SlugHasPrefix(v string) predicate.Project
- func SlugHasSuffix(v string) predicate.Project
- func SlugIn(vs ...string) predicate.Project
- func SlugLT(v string) predicate.Project
- func SlugLTE(v string) predicate.Project
- func SlugNEQ(v string) predicate.Project
- func SlugNotIn(vs ...string) predicate.Project
- func TotalValue(v string) predicate.Project
- func TotalValueContains(v string) predicate.Project
- func TotalValueContainsFold(v string) predicate.Project
- func TotalValueEQ(v string) predicate.Project
- func TotalValueEqualFold(v string) predicate.Project
- func TotalValueGT(v string) predicate.Project
- func TotalValueGTE(v string) predicate.Project
- func TotalValueHasPrefix(v string) predicate.Project
- func TotalValueHasSuffix(v string) predicate.Project
- func TotalValueIn(vs ...string) predicate.Project
- func TotalValueLT(v string) predicate.Project
- func TotalValueLTE(v string) predicate.Project
- func TotalValueNEQ(v string) predicate.Project
- func TotalValueNotIn(vs ...string) predicate.Project
- func ValidColumn(column string) bool
- func ValueDecimal(v int) predicate.Project
- func ValueDecimalEQ(v int) predicate.Project
- func ValueDecimalGT(v int) predicate.Project
- func ValueDecimalGTE(v int) predicate.Project
- func ValueDecimalIn(vs ...int) predicate.Project
- func ValueDecimalLT(v int) predicate.Project
- func ValueDecimalLTE(v int) predicate.Project
- func ValueDecimalNEQ(v int) predicate.Project
- func ValueDecimalNotIn(vs ...int) predicate.Project
- type OrderOption
- func ByAddress(opts ...sql.OrderTermOption) OrderOption
- func ByForecastedApr(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByLaunchpadField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByMintField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func BySlot(opts ...sql.OrderTermOption) OrderOption
- func BySlug(opts ...sql.OrderTermOption) OrderOption
- func ByTotalValue(opts ...sql.OrderTermOption) OrderOption
- func ByValueDecimal(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the project type in the database. Label = "project" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldAddress holds the string denoting the address field in the database. FieldAddress = "address" // FieldSlot holds the string denoting the slot field in the database. FieldSlot = "slot" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldSlug holds the string denoting the slug field in the database. FieldSlug = "slug" // FieldValueDecimal holds the string denoting the value_decimal field in the database. FieldValueDecimal = "value_decimal" // FieldForecastedApr holds the string denoting the forecasted_apr field in the database. FieldForecastedApr = "forecasted_apr" // FieldTotalValue holds the string denoting the total_value field in the database. FieldTotalValue = "total_value" // FieldPaymentToken holds the string denoting the payment_token field in the database. FieldPaymentToken = "payment_token" // FieldMetadata holds the string denoting the metadata field in the database. FieldMetadata = "metadata" // EdgeMint holds the string denoting the mint edge name in mutations. EdgeMint = "mint" // EdgeLaunchpad holds the string denoting the launchpad edge name in mutations. EdgeLaunchpad = "launchpad" // Table holds the table name of the project in the database. Table = "projects" // MintTable is the table that holds the mint relation/edge. MintTable = "mints" // MintInverseTable is the table name for the Mint entity. // It exists in this package in order to avoid circular dependency with the "mint" package. MintInverseTable = "mints" // MintColumn is the table column denoting the mint relation/edge. MintColumn = "project_mint" // LaunchpadTable is the table that holds the launchpad relation/edge. LaunchpadTable = "launchpads" // LaunchpadInverseTable is the table name for the Launchpad entity. // It exists in this package in order to avoid circular dependency with the "launchpad" package. LaunchpadInverseTable = "launchpads" // LaunchpadColumn is the table column denoting the launchpad relation/edge. LaunchpadColumn = "project_launchpad" )
Variables ¶
var Columns = []string{ FieldID, FieldAddress, FieldSlot, FieldName, FieldSlug, FieldValueDecimal, FieldForecastedApr, FieldTotalValue, FieldPaymentToken, FieldMetadata, }
Columns holds all SQL columns for project fields.
Functions ¶
func Address ¶
Address applies equality check predicate on the "address" field. It's identical to AddressEQ.
func AddressContains ¶
AddressContains applies the Contains predicate on the "address" field.
func AddressContainsFold ¶
AddressContainsFold applies the ContainsFold predicate on the "address" field.
func AddressEqualFold ¶
AddressEqualFold applies the EqualFold predicate on the "address" field.
func AddressGTE ¶
AddressGTE applies the GTE predicate on the "address" field.
func AddressHasPrefix ¶
AddressHasPrefix applies the HasPrefix predicate on the "address" field.
func AddressHasSuffix ¶
AddressHasSuffix applies the HasSuffix predicate on the "address" field.
func AddressLTE ¶
AddressLTE applies the LTE predicate on the "address" field.
func AddressNEQ ¶
AddressNEQ applies the NEQ predicate on the "address" field.
func AddressNotIn ¶
AddressNotIn applies the NotIn predicate on the "address" field.
func ForecastedApr ¶
ForecastedApr applies equality check predicate on the "forecasted_apr" field. It's identical to ForecastedAprEQ.
func ForecastedAprContains ¶
ForecastedAprContains applies the Contains predicate on the "forecasted_apr" field.
func ForecastedAprContainsFold ¶
ForecastedAprContainsFold applies the ContainsFold predicate on the "forecasted_apr" field.
func ForecastedAprEQ ¶
ForecastedAprEQ applies the EQ predicate on the "forecasted_apr" field.
func ForecastedAprEqualFold ¶
ForecastedAprEqualFold applies the EqualFold predicate on the "forecasted_apr" field.
func ForecastedAprGT ¶
ForecastedAprGT applies the GT predicate on the "forecasted_apr" field.
func ForecastedAprGTE ¶
ForecastedAprGTE applies the GTE predicate on the "forecasted_apr" field.
func ForecastedAprHasPrefix ¶
ForecastedAprHasPrefix applies the HasPrefix predicate on the "forecasted_apr" field.
func ForecastedAprHasSuffix ¶
ForecastedAprHasSuffix applies the HasSuffix predicate on the "forecasted_apr" field.
func ForecastedAprIn ¶
ForecastedAprIn applies the In predicate on the "forecasted_apr" field.
func ForecastedAprIsNil ¶
ForecastedAprIsNil applies the IsNil predicate on the "forecasted_apr" field.
func ForecastedAprLT ¶
ForecastedAprLT applies the LT predicate on the "forecasted_apr" field.
func ForecastedAprLTE ¶
ForecastedAprLTE applies the LTE predicate on the "forecasted_apr" field.
func ForecastedAprNEQ ¶
ForecastedAprNEQ applies the NEQ predicate on the "forecasted_apr" field.
func ForecastedAprNotIn ¶
ForecastedAprNotIn applies the NotIn predicate on the "forecasted_apr" field.
func ForecastedAprNotNil ¶
ForecastedAprNotNil applies the NotNil predicate on the "forecasted_apr" field.
func HasLaunchpad ¶
HasLaunchpad applies the HasEdge predicate on the "launchpad" edge.
func HasLaunchpadWith ¶
HasLaunchpadWith applies the HasEdge predicate on the "launchpad" edge with a given conditions (other predicates).
func HasMintWith ¶
HasMintWith applies the HasEdge predicate on the "mint" edge with a given conditions (other predicates).
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func SlugContains ¶
SlugContains applies the Contains predicate on the "slug" field.
func SlugContainsFold ¶
SlugContainsFold applies the ContainsFold predicate on the "slug" field.
func SlugEqualFold ¶
SlugEqualFold applies the EqualFold predicate on the "slug" field.
func SlugHasPrefix ¶
SlugHasPrefix applies the HasPrefix predicate on the "slug" field.
func SlugHasSuffix ¶
SlugHasSuffix applies the HasSuffix predicate on the "slug" field.
func TotalValue ¶
TotalValue applies equality check predicate on the "total_value" field. It's identical to TotalValueEQ.
func TotalValueContains ¶
TotalValueContains applies the Contains predicate on the "total_value" field.
func TotalValueContainsFold ¶
TotalValueContainsFold applies the ContainsFold predicate on the "total_value" field.
func TotalValueEQ ¶
TotalValueEQ applies the EQ predicate on the "total_value" field.
func TotalValueEqualFold ¶
TotalValueEqualFold applies the EqualFold predicate on the "total_value" field.
func TotalValueGT ¶
TotalValueGT applies the GT predicate on the "total_value" field.
func TotalValueGTE ¶
TotalValueGTE applies the GTE predicate on the "total_value" field.
func TotalValueHasPrefix ¶
TotalValueHasPrefix applies the HasPrefix predicate on the "total_value" field.
func TotalValueHasSuffix ¶
TotalValueHasSuffix applies the HasSuffix predicate on the "total_value" field.
func TotalValueIn ¶
TotalValueIn applies the In predicate on the "total_value" field.
func TotalValueLT ¶
TotalValueLT applies the LT predicate on the "total_value" field.
func TotalValueLTE ¶
TotalValueLTE applies the LTE predicate on the "total_value" field.
func TotalValueNEQ ¶
TotalValueNEQ applies the NEQ predicate on the "total_value" field.
func TotalValueNotIn ¶
TotalValueNotIn applies the NotIn predicate on the "total_value" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func ValueDecimal ¶
ValueDecimal applies equality check predicate on the "value_decimal" field. It's identical to ValueDecimalEQ.
func ValueDecimalEQ ¶
ValueDecimalEQ applies the EQ predicate on the "value_decimal" field.
func ValueDecimalGT ¶
ValueDecimalGT applies the GT predicate on the "value_decimal" field.
func ValueDecimalGTE ¶
ValueDecimalGTE applies the GTE predicate on the "value_decimal" field.
func ValueDecimalIn ¶
ValueDecimalIn applies the In predicate on the "value_decimal" field.
func ValueDecimalLT ¶
ValueDecimalLT applies the LT predicate on the "value_decimal" field.
func ValueDecimalLTE ¶
ValueDecimalLTE applies the LTE predicate on the "value_decimal" field.
func ValueDecimalNEQ ¶
ValueDecimalNEQ applies the NEQ predicate on the "value_decimal" field.
func ValueDecimalNotIn ¶
ValueDecimalNotIn applies the NotIn predicate on the "value_decimal" field.
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Project queries.
func ByAddress ¶
func ByAddress(opts ...sql.OrderTermOption) OrderOption
ByAddress orders the results by the address field.
func ByForecastedApr ¶
func ByForecastedApr(opts ...sql.OrderTermOption) OrderOption
ByForecastedApr orders the results by the forecasted_apr field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByLaunchpadField ¶
func ByLaunchpadField(field string, opts ...sql.OrderTermOption) OrderOption
ByLaunchpadField orders the results by launchpad field.
func ByMintField ¶
func ByMintField(field string, opts ...sql.OrderTermOption) OrderOption
ByMintField orders the results by mint field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func BySlot ¶
func BySlot(opts ...sql.OrderTermOption) OrderOption
BySlot orders the results by the slot field.
func BySlug ¶
func BySlug(opts ...sql.OrderTermOption) OrderOption
BySlug orders the results by the slug field.
func ByTotalValue ¶
func ByTotalValue(opts ...sql.OrderTermOption) OrderOption
ByTotalValue orders the results by the total_value field.
func ByValueDecimal ¶
func ByValueDecimal(opts ...sql.OrderTermOption) OrderOption
ByValueDecimal orders the results by the value_decimal field.